package com.unis.inspectiontask.client;
import com.unis.inspectiontask.common.vo.*;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.util.List;

/**
 * @author 张琪
 * @date 2019年8月27日 下午2:16:33
 * @description 日常任务检查 TaskFeign
 * @
 */

@FeignClient(name = "inspectiontask-server")
@Component
@Api(value = "日常检查任务管理", tags = "日常检查任务管理维护")
public interface TaskFeign {

	/**
	 * 分页日常检查信息查询
	 * @param taskQueryVO
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@ApiOperation(value = "根据条件分页日常检查信息列表",notes = "参数：被检单位编号，被检单位名称，检查单位编号，检查单位名称，检查开始时间，检查结束时间")
	@PostMapping(value = "/inspectionTaskPageList/{pageNum}/{pageSize}")
	public ResponseWrapper getRwTaskPageList(@RequestBody TaskQueryVO taskQueryVO,
			   @PathVariable(value = "pageNum") Integer pageNum,
			   @PathVariable(value = "pageSize") Integer pageSize);

	/**
	 * 根据编码查询详单数据
	 * @param rwId
	 * @return
	 */
	@ApiOperation(value = "根据编码查询详单数据")
	@GetMapping(value = "/inspectionTaskCode/{rwId}/{jhId}")
	public ResponseWrapper getTaskInfoByrwbh(@PathVariable("rwId")String rwId,@PathVariable("jhId")String jhId) ;

	/**
	 * 根据检查单位ID和计划编号查询详单数据+检查组
	 * @param jcdwId
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "根据检查单位ID和计划编号查询详单数据+检查组",notes = "参数：jcdwId-检查单位ID   jhId：计划编号 ")
	@GetMapping(value = "/inspectionTaskInfoAll/{jcdwId}/{jhId}")
	public ResponseWrapper getTaskInfoAll(@PathVariable("jcdwId")String jcdwId,@PathVariable("jhId")String jhId) ;

	/**
	 *  分配操作中检查项目，检查内容数据暂存数据
	 */
	@ApiOperation(value = "分配操作中暂存数据-日常检查任务表+任务检查项目表+ 检查内容表",
			notes = "参数：任务编号，任务名称，检查项目 ，检查内容 ， 检查单位 ， 检查方式 ")
	@PostMapping(value = "/inspectionTaskDistribution")
	public ResponseWrapper inspectionTaskDistribution(@RequestBody TaskVO taskVO) ;

 /**
	 * 制定任务检查数据新增对接
	 * @return
	 */
	@ApiOperation(value = "制定任务对接检查新增接口",
			notes = "参数：任务编号，任务名称，计划编号，检查方式（0，远程。1、现场），检查组取得方式（0，指定。1、双随机。2、指定。），"
					+ "检查单位ID , 检查单位名称 , 下发人 , 下发人名称 , 下发时间 , 任务状态（0、待分配。1、待下发。2、已下发。3、已完成），"
					+ "任务类型，是否分配本级检查组值，被检单位选择方式（0,单一 1，组合），任务起日，任务止日   sffp: 是否选择检查组")
	@PostMapping(value = "/inspectionTaskInsert")
	public ResponseWrapper inspectionTaskInsert(@RequestBody TaskVO  taskVO) ;

	 /**
	 * 制定任务检查组+数据新增对接
	 * @param taskTO
	 * @return
	 */
	@ApiOperation(value = "制定任务检查组+数据新增对接",notes = "参数：是否分配本级检查组")
	@PostMapping(value = "/inspectionTaskInsertTeam")
	public ResponseWrapper inspectionTaskInsertTeam(@RequestBody TaskTeamVO  taskTeamVO) ;

	/**
	 * 任务结果下发-新增
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务结果下发-新增")
	@PostMapping(value = "/inspectionTaskResultInsert")
	public ResponseWrapper updateInspectionTask(@RequestBody TaskVO taskVO);

	/**
	 * 制定任务回撤
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务回撤",notes = "参数：计划ID")
	@PostMapping(value = "/inspectionTaskGetDate/{jhId}")
	public ResponseWrapper inspectionTaskGetDate(@PathVariable("jhId")String jhId) ;


	/**
	 * 根据条件导出日常检查管理信息
	 * @param taskQueryVO
	 * @return
	 */
    @ApiOperation(value = "根据条件导出日常检查管理信息", notes = "参数：查询条件")
    @PostMapping(value = "/inspectionTaskExport")
    public ResponseWrapper inspectionTaskExport(@RequestBody TaskQueryVO taskQueryVO);

    /**
     *  修改任务状态
     * @param taskVO
     * @return
     */
	@ApiOperation(value = "修改任务状态",notes = "参数：rwId-任务编号 rwZt-任务状态 （0、待分配。1、待下发。2、已下发。3、已完成）")
	@PutMapping(value = "/inspectionTaskUpdateByEntity/{rwId}/{rwZt}")
	public ResponseWrapper inspectionTaskUpdateByEntity(@PathVariable("rwId")String rwId,@PathVariable("rwZt")Integer rwZt) ;

	/**
	 * 获取任务ID主键策略方法  计划编号+001 格式
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "获取任务ID主键策略方法  计划编号+001 格式",notes = "参数：jhId-计划编号")
	@GetMapping(value = "/inspectionTaskMaxCodeById/{jhId}")
	public ResponseWrapper inspectionTaskMaxCodeById(@PathVariable("jhId")String jhId);

	/**
	 * 检查任务数据 新增
	 * @param taskVO
	 */
	 @ApiOperation(value = "任务检查新增")
	 @PutMapping(value = "/inspectionTaskSave")
	public ResponseWrapper inspectionTaskSave(@RequestBody TaskVO taskVO);

	/**
	 * 检查任务数据 删除
	 * @param rwId
	 * @return
	 */
	 @ApiOperation(value = "任务检查删除")
	 @DeleteMapping(value = "/inspectionTaskDelete/{rwId}")
	public ResponseWrapper inspectionTaskDelete(@PathVariable("rwId")String rwId);

	/**
	 * 检查任务数据 删除
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查删除")
	@PostMapping(value = "/inspectionTask/deleteByEntity")
	public ResponseWrapper deleteByEntity(@RequestBody TaskVO taskVO);

	/**
	 *  检查任务子项目数据 删除
	 * @param rwId
	 */
	 @ApiOperation(value = "检查任务子项目数据删除")
	 @DeleteMapping(value = "/taskCheckItemsVODelete/{rwId}")
	public ResponseWrapper taskCheckItemsVODelete(@PathVariable("rwId") String rwId);

	/**
	 * 检查任务子项目数据 新增
	 * @param taskCheckItemsVO
	 */
	 @ApiOperation(value = "检查任务子项目数据新增")
	 @PutMapping(value = "/taskCheckItemsVOSave")
	public ResponseWrapper taskCheckItemsVOSave(@RequestBody TaskCheckItemsVO taskCheckItemsVO);

	 /**
	 * 检查任务内容数据 删除
	 * @param rwId
	 */
	 @ApiOperation(value = "检查任务子项目数据删除")
	 @DeleteMapping(value = "/checkContentVODelete/{rwId}")
	public ResponseWrapper checkContentVODelete(@PathVariable("rwId")  String rwId);

	/**
	 * 检查任务内容数据 新增
	 * @param checkContentVO
	 */
	 @ApiOperation(value = "检查任务内容数据 新增")
	 @PutMapping(value = "/checkContentVOSave")
	public ResponseWrapper checkContentVOSave(@RequestBody CheckContentVO checkContentVO);

    /**
	 * 检查任务内容数据 新增
	 * @param taskVO
	 */
	 @ApiOperation(value = "检查任务内容数据 新增")
	 @PutMapping(value = "/inspectionTaskUpdate")
	public ResponseWrapper inspectionTaskUpdate(@RequestBody TaskVO taskVO);

	 /**
	  * 检查任务-归档管理
	  * @param taskVO
	  * @return
	  */
	 @ApiOperation(value = "检查任务-归档管理")
	 @PutMapping(value = "/inspectionTaskGuiDang")
	 public ResponseWrapper inspectionTaskGuiDang(@RequestBody TaskVO taskVO) ;

	 /**
	  * 制定任务 根据计划ID查询列表
	  * @param jhId
	  * @return
	  */
	@ApiOperation(value = "制定任务 根据计划ID查询列表",notes = "参数：计划编号，被检单位ID")
	@PostMapping(value = "/inspectionPlanList/{jhId}")
	public ResponseWrapper inspectionPlanList(@PathVariable("jhId")String jhId);

	 /**
	 * 检查任务数据 更新
	 * @param taskVO
	 * @return
	 */
	 @ApiOperation(value = "任务检查 【更新】")
	 @PutMapping(value = "/inspectionTaskEdit")
	public ResponseWrapper inspectionTaskEdit(@RequestBody TaskVO taskVO) ;

	/**
	 * 任务检查数据查询
	 * @param taskQueryVO
	 * @return
	 */
	 @ApiOperation(value = "任务检查 【数据】")
	 @PostMapping(value = "/inspectionTaskMain")
	public ResponseWrapper inspectionTaskMain(@RequestBody TaskQueryVO taskQueryVO);

	/**
	 * @Title: inspectionJhTaskCq
	 * @Description:方法描述:(这里用一句话描述这个方法的作用)
	 * @param @param taskQueryVO
	 * @param @return    设定文件
	 * @return ResponseWrapper    返回类型
	 * @throws
	*/
	 @ApiOperation(value = "任务派发计划定时任务检查是否超期 【数据】")
	 @PostMapping(value = "/inspectionJhTaskCq")
	public ResponseWrapper inspectionJhTaskCq(TaskQueryVO taskQueryVO);

	@ApiOperation(value = "检查任务-通过检查组人员查询任务编号",notes = "参数：组员编号")
	@PostMapping(value = "/taskListByZyId/{zyId}")
	public ResponseWrapper getTaskListByZyId(@PathVariable("zyId") String zyId);

	@ApiOperation(value = "检查任务-通过任务列表查询组员人数",notes = "参数：任务列表")
	@PostMapping(value = "/getCountByRwIdList")
	public ResponseWrapper getCountByRwIdList(@RequestBody List<String> rwIdList);

	/**
	 *
	 * @Description: 通过任务下发人查询任务Id列表
	 * @author: 王帅
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过任务下发人查询任务Id列表", notes = "通过任务下发人查询任务Id列表")
	@PostMapping("/makers/taskIds")
	public ResponseWrapper getTaskIdsByMakers(@RequestParam(value = "makersId") List<String> makersId);

	@ApiOperation(value = "根据计划编号和被检单位编号查询任务列表",notes = "参数：jhId：计划编号 bjdwId：被检单位编号")
	@GetMapping(value = "/inspectionTaskInfoByjhId/{jhId}/{bjdwId}")
	public ResponseWrapper getTaskInfoByjhId(@PathVariable("jhId")String jhId,@PathVariable("bjdwId")String bjdwId);

	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过组织机构Id或是创建人集合查询检查计划主键集合", notes = "通过组织机构Id或是创建人集合查询检查计划主键集合")
	@ApiImplicitParams({ @ApiImplicitParam(name = "orgCode", value = "组织机构编码", required = false, paramType = "query"),
			@ApiImplicitParam(name = "makersId", value = "创建人集合", dataType = "list", required = false, paramType = "query"),
			@ApiImplicitParam(name = "taskStatus", value = "任务状态", paramType = "query", required = false)})
	@GetMapping("/orgCodeOrMakers/planIds")
	public ResponseWrapper getPlanIdsByOrgCodeOrMakers(@RequestParam(name = "orgCode", required = false) String orgCode,
			@RequestParam(name = "makersId", required = false) List<String> makersId,@RequestParam(name = "taskStatus", required = false)String taskStatus);



	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更申请", notes = "变更申请")
	@PostMapping("/task/apply")
	public ResponseWrapper taskChange(@RequestBody TaskChangeVO taskChangeVO);


	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更审核", notes = "变更审核")
	@PostMapping("/task/examine")
	public ResponseWrapper taskExamine(@RequestBody TaskChangeVO taskChangeVO);

	@ApiOperation(value = "查询区级任务列表", notes = "变更审核")
	@PostMapping("/task/list")
	public ResponseWrapper taskList(@RequestBody ResultApplyQuery taskChangeVO);

	@ApiOperation(value = "更新检查人信息", notes = "更新检查人信息")
	@PostMapping("/task/updateTJczzy")
	public ResponseWrapper updateTJczzy(@RequestBody TaskVO taskVO);
}
