/**
 * @Title: EvasionFeign.java
 * @Package com.unis.inspectiontask.client
 * @Description:
 * @author LiuFeng
 * @date 2019年8月24日 下午4:49:00
 * @version V1.0
 */
package com.unis.inspectiontask.client;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.common.vo.TeamVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

/**
 * @ClassName: TeamFeign
 * @Description: 检查组管理 Feign
 * @author LiuFeng
 * @date 2019年8月26日 下午4:33:00
 */

@FeignClient(name = "inspectiontask-server")
@Component
@Api(value = "检查组维护管理", tags = "检查组维护管理")
public interface TeamFeign {

	/**
	 *
	 * @Title: inspectionTeams
	 * @Description: 检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "检查组信息保存", notes = "参数：检查组名称，检查组人员列表，被检单位列表，任务id")
    @PostMapping(value = "/inspectionTeams")
    public ResponseWrapper saveInspectionTeams(@RequestBody List<TeamVO> teamVOs);

	/**
	 *
	 * @Title: saveInspectionTeams
	 * @Description: 检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "检查组信息修改", notes = "参数：检查组VO")
    @PutMapping(value = "/inspectionTeams")
    public ResponseWrapper updateInspectionTeams(@RequestBody List<TeamVO> teamVOs);

	/**
	 *
	 * @Title: saveInspectionTeams
	 * @Description: 根据当前用户查询被检单位
	 * @param userId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据用户ID查询被检单位", notes = "参数：用户id")
	@GetMapping(value = "/inspectionUnit/{userId}")
    public ResponseWrapper getInspectionUnit(@PathVariable(value="userId")String userId);

	/**
	 *
	 * @Title: getIinspectionTeamList
	 * @Description: 根据用户id获取检查组列表
	 * @param taskId 任务编号
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据任务编号查询被检单位", notes = "参数：任务编号")
	@GetMapping(value = "/inspectionTeamList/{taskId}")
    public ResponseWrapper getIinspectionTeamList(@PathVariable(value="taskId")String taskId);

	/**
	 *
	 * @Title: getIinspectionTeam
	 * @Description: 根据组织编号判断是否在检查组
	 * @param jczId 检查组id
	 * @param orgId 组织id
	 * @return ResponseWrapper  data: 0 :不再检查组   1:在检查组
	 * @throws
	 */
	@ApiOperation(value = "根据组织编号判断是否在检查组", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/isInspectionTeam")
    public ResponseWrapper isIinspectionTeam(
    		@ApiParam(value="检查组id",name="jczId",required=true)
    		@RequestParam(value="jczId")Long jczId,
    		@ApiParam(value="组织编号",name="orgId",required=true)
    		@RequestParam(value="orgId")String orgId);

	@ApiOperation(value = "根据检查组人员编号判断查询任务列表", notes = "参数：人员编号")
    @GetMapping(value = "/taskList/{rybh}")
    public ResponseWrapper getTaskList(@PathVariable(value="rybh")String rybh);

	@ApiOperation(value = "根据任务编号和被检单位id查询检查组信息", notes = "参数：任务编号,被检企业id")
    @GetMapping(value = "/inspectionTeam/{rwId}/{bjdwId}")
    public ResponseWrapper getInspectionTeam(
    		@PathVariable(value="rwId")String rwId,
    		@PathVariable(value="bjdwId")String bjdwId);

	/**
	 * 根据任务编号删除检查组所有信息
	 * @param teamVO
	 */
	@ApiOperation(value = "根据任务编号删除检查组所有信息", notes = "参数：任务编号")
	@DeleteMapping(value = "/deleteInspectionTeams/{rwId}")
	public ResponseWrapper deleteInspectionTeams(	@PathVariable(value="rwId")String rwId);

	/**
	 *
	 * @Title: taskList
	 * @Description: 根据检查组人员编号 任务类型   判断查询任务列表
	 * @param rybh 人员编号 rwlx任务类型
	 * @return
	 * @throws
	 */
	@ApiOperation(value = "根据检查组人员编号/任务类型判断查询任务列表", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/taskListMore/{rybh}/{rwlx}")
    public ResponseWrapper getTaskListMore(@PathVariable(value="rybh")String rybh,@PathVariable(value="rwlx")String rwlx);

	/**
	 *
	 * @Title: saveInspectionTeams
	 * @Description: 制定任务检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "制定任务检查组信息暂存/下发", notes = "参数：")
    @PostMapping(value = "/saveInspectionPlanTeams")
	public ResponseWrapper saveInspectionPlanTeams(List<TeamVO> teamVOs);

	/**
	 *
	 * @Description: 通过组员Id获取任务Id集合
	 * @author: 王帅
	 * @param: @param  memberId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过组员Id获取任务Id集合", notes = "通过组员Id获取任务Id集合")
	@GetMapping(value = "/taskIds/{memberId}")
	public ResponseWrapper getTaskIdsListByMemberId(@PathVariable(value = "memberId")String memberId);
}
