package com.unis.inspectiontask.server.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.common.vo.EvasionQueryVO;
import com.unis.inspectiontask.common.vo.EvasionVO;
import com.unis.inspectiontask.server.service.EvasionService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 *
 * @ClassName: EvasionController
 * @Description: 人员、被检单位规避controller
 * @author LiuFeng
 * @date 2019年8月24日 下午2:05:09
 *
 */
@RestController
@Slf4j
@Api(value = "检查组规避", tags = "检查组人员，被检单位规避维护")
public class EvasionController {

	@Autowired
	private EvasionService evasionService;

	/**
	 *
	 * @Title: saveRecords
	 * @Description:
	 * @param evasionVO
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "规避记录保存", notes = "参数：规避人员，单位code、名称、rwid")
    @PostMapping(value = "/evasionRecords")
    public ResponseWrapper saveRecords(@RequestBody List<EvasionVO> evasionVOs){
        try {
        	evasionService.saveRecords(evasionVOs);
        	return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", evasionVOs);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "保存失败", null);
        }
    }

	/**
	 *
	 * @Title: evasionList
	 * @Description: 规避人员，单位记录条件查询
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "规避记录查询", notes = "参数：任务id")
    @GetMapping(value = "/evasionList/{rwId}")
    public ResponseWrapper queryEvasionList(@PathVariable(value="rwId")String rwId){
        try {
        	List<EvasionVO>  evasionVOs = evasionService.queryRecordsByRwId(rwId);
        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", evasionVOs);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

}
