package com.unis.inspectiontask.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.common.vo.PerformanceQueryVO;
import com.unis.inspectiontask.common.vo.PerformanceVO;
import com.unis.inspectiontask.common.vo.PersonnelPerformanceQueryVO;
import com.unis.inspectiontask.server.service.PerformanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @author WangZL
 * @version 1.0
 * @Title PerformanceController
 * @ProjectName 履职情况表 PerformanceController
 * @Description
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "履职情况表 ", tags = "履职情况表")
@Slf4j
public class PerformanceController {

	@Autowired
	private PerformanceService performanceService;

	/**
	 * @author WangZL
	 * @Description 履职情况-分页查询列表
	 * @param
	 * @return
	 */
	@SuppressWarnings("deprecation")
	@ApiOperation(value = "履职情况-分页查询列表", notes = "参数：人员信息列表，统计开始时间，统计结束时间")
	@PostMapping(value = "/performanceList/{pageNum}/{pageSize}")
	public ResponseWrapper getPerformancePage(@RequestBody PerformanceQueryVO performanceQueryVO, @PathVariable("pageNum")Integer pageNum, @PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<PerformanceVO> pageInfos = new PageInfo<PerformanceVO>(performanceService.getPerformancePage(performanceQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 履职情况-检查次数
	 * @param
	 * @return
	 */
	@SuppressWarnings("deprecation")
	@ApiOperation(value = "人员履职-检查次数", notes = "参数：任务id，任务集合，字典code，字典集合")
	@PostMapping(value = "/personnelPerformanceNumber")
	public ResponseWrapper getPersonnelPerformanceNumber(@RequestBody PersonnelPerformanceQueryVO personnelPerformanceQueryVO) {
		try{
			if (personnelPerformanceQueryVO.getDictCode() == null && personnelPerformanceQueryVO.getDictCodeList() == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			Integer number = performanceService.personnelPerformanceNumber(personnelPerformanceQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), number);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}


}
