package com.unis.inspectiontask.server.controller;

import java.util.List;

import com.unis.inspectiontask.common.constant.TaskStatusConstant;
import com.unis.inspectiontask.common.vo.*;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.server.service.TaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;

/**
 *
 * @ClassName: TaskController
 * @Description: 日常检查任务管理controller
 * @author ZhangQi
 * @date 2019年8月24日 下午2:05:09
 *
 */
@RestController
@Slf4j
@Api(value = "检查任务管理", tags = "检查任务管理维护")
public class TaskController {
	/**
	 * 日常检查任务业务
	 */
	@Autowired
	private TaskService taskService;

	/**
	 * 根据条件分页日常检查信息列表
	 *
	 * @param taskQueryVO
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@SuppressWarnings("deprecation")
	@ApiOperation(value = "任务检查列表 根据条件【分页查询】", notes = "参数：被检单位编号，被检单位名称，检查单位编号，检查单位名称，检查开始时间，检查结束时间")
	@PostMapping(value = "/inspectionTaskPageList/{pageNum}/{pageSize}")
	public ResponseWrapper getRwTaskPageList(@RequestBody TaskQueryVO taskQueryVO,
			@PathVariable(value = "pageNum") Integer pageNum, @PathVariable(value = "pageSize") Integer pageSize) {
		try {
			taskQueryVO.setRwZtOperate(">=");
			taskQueryVO.setRwZt(Integer.valueOf(TaskStatusConstant.TO_FP.getValue()));
			PageInfo<TaskVO> pageInfos = taskService.getRwTaskPageList(taskQueryVO, pageNum, pageSize);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", pageInfos);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}
	}

	/**
	 * 制定任务 根据计划ID查询列表
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务 根据计划ID查询列表", notes = "参数：计划编号，被检单位ID")
	@PostMapping(value = "/inspectionPlanList/{jhId}")
	public ResponseWrapper inspectionPlanList(@PathVariable("jhId") String jhId) {
		try {
			List<TaskPlanVo> taskVo = taskService.getPlanList(jhId);
			if (taskVo.size() == 0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", taskVo);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}

	}

	/**
	 * 检查任务-通过检查组人员查询任务编号
	 *
	 * @param zyId
	 * @return
	 */
	@ApiOperation(value = "检查任务-通过检查组人员查询任务编号", notes = "参数：组员编号")
	@PostMapping(value = "/taskListByZyId/{zyId}")
	public ResponseWrapper getTaskListByZyId(@PathVariable("zyId") String zyId) {
		try {
			List<String> rwIdList = taskService.getTaskListByZyId(zyId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", rwIdList);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}
	}

	/**
	 * 检查任务-通过检查组人员查询任务编号
	 *
	 * @param rwIdList
	 * @return
	 */
	@ApiOperation(value = "检查任务-通过任务列表查询组员人数", notes = "参数：任务列表")
	@PostMapping(value = "/getCountByRwIdList")
	public ResponseWrapper getCountByRwIdList(@RequestBody List<String> rwIdList) {
		try {
			Integer countZy = taskService.getCountByRwIdList(rwIdList);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取信息列表成功", countZy);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "获取信息列表失败", null);
		}
	}

	/**
	 * @author zhangQi
	 * @Description 根据任务编码查询检查任务详细信息
	 * @return 日常检查
	 */
	@ApiOperation(value = "任务检查分配 根据任务编号和计划ID【数据回显】", notes = "参数：rwId-任务编号 jhId-计划编号")
	@GetMapping(value = "/inspectionTaskCode/{rwId}/{jhId}")
	public ResponseWrapper getTaskInfoByrwbh(@PathVariable("rwId") String rwId, @PathVariable("jhId") String jhId) {
		try {
			TaskVO taskVo = taskService.getTaskInfoByrwbh(rwId);
			if (taskVo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", taskVo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 根据检查单位ID和计划编号查询详单数据+检查组
	 *
	 * @param jcdwId
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务编辑 根据检查单位ID和计划编号【数据回显】详情+检查组", notes = "参数：jcdwId-检查单位ID   jhId：计划编号 ")
	@GetMapping(value = "/inspectionTaskInfoAll/{jcdwId}/{jhId}")
	public ResponseWrapper getTaskInfoAll(@PathVariable("jcdwId") String jcdwId, @PathVariable("jhId") String jhId) {
		try {
			TaskVO taskVO = new TaskVO();
			taskVO.setJcdwId(jcdwId);
			taskVO.setJhId(jhId);
			TaskVO taskVo = taskService.getTaskInfoAll(taskVO);
			if (taskVo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", taskVo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 根据计划编号和被检单位编号查询任务列表
	 * @param jhId
	 * @param bjdwId
	 * @return
	 */
	@ApiOperation(value = "根据计划编号和被检单位编号查询任务列表",notes = "参数：jhId：计划编号 bjdwId：被检单位编号")
	@GetMapping(value = "/inspectionTaskInfoByjhId/{jhId}/{bjdwId}")
	public ResponseWrapper getTaskInfoByjhId(@PathVariable("jhId")String jhId,@PathVariable("bjdwId")String bjdwId) {
		try {
			List<TaskVO> taskList = taskService.getTaskInfoByjhId(jhId,bjdwId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "获取成功", taskList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * 检查任务数据 新增Add
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查 【新增】")
	@PutMapping(value = "/inspectionTaskSave")
	public ResponseWrapper inspectionTaskSave(@RequestBody TaskVO taskVO) {
		try {
			taskService.inspectionSaveJcDate(taskVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "新增失败", null);
		}
	}

	/**
	 * 检查任务子项目数据 新增
	 *
	 * @param taskCheckItemsVO
	 */
	@ApiOperation(value = "检查任务子项目 【新增】")
	@PutMapping(value = "/taskCheckItemsVOSave")
	public ResponseWrapper taskCheckItemsVOSave(@RequestBody TaskCheckItemsVO taskCheckItemsVO) {
		try {
			taskService.inspectionJczxSave(taskCheckItemsVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "新增失败", null);
		}
	}

	/**
	 * 检查任务数据 删除
	 *
	 * @param rwId
	 * @return
	 */
	@ApiOperation(value = "任务检查 【删除】")
	@DeleteMapping(value = "/inspectionTaskDelete/{rwId}")
	public ResponseWrapper inspectionTaskDelete(@PathVariable("rwId") String rwId) {
		try {
			taskService.inspectionTaskDelete(rwId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
		}
	}

	/**
	 * 检查任务数据 删除
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查删除")
	@PostMapping(value = "/inspectionTask/deleteByEntity")
	public ResponseWrapper deleteByEntity(@RequestBody TaskVO taskVO) {
		return taskService.deleteByEntity(taskVO);
	}

	/**
	 * 检查任务子项目数据 删除
	 *
	 * @param rwId
	 */
	@ApiOperation(value = "检查任务子项目 【删除】")
	@DeleteMapping(value = "/taskCheckItemsVODelete/{rwId}")
	public ResponseWrapper taskCheckItemsVODelete(@PathVariable("rwId") String rwId) {
		try {
			taskService.inspectionTaskCheckItemsDelete(rwId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
		}
	}

	/**
	 * 检查任务内容数据 删除
	 *
	 * @param rwId
	 */
	@ApiOperation(value = "检查任务内容删除")
	@DeleteMapping(value = "/checkContentVODelete/{rwId}")
	public ResponseWrapper checkContentVODelete(@PathVariable("rwId") String rwId) {
		try {
			taskService.inspectionTaskcheckContentDelete(rwId);
			return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
		}
	}

	/**
	 * 检查任务内容数据 新增
	 *
	 * @param checkContentVO
	 */
	@ApiOperation(value = "检查任务内容 【新增】")
	@PutMapping(value = "/checkContentVOSave")
	public ResponseWrapper checkContentVOSave(@RequestBody CheckContentVO checkContentVO) {
		try {
			taskService.inspectionJcnrSave(checkContentVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "新增成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "新增失败", null);
		}
	}

	/**
	 * 分配操作中检查项目，检查内容数据暂存数据
	 *
	 * @param tJcrwDO
	 * @param tJcnrDO
	 * @param tRwjcxmDO
	 */
	@ApiOperation(value = "任务检查 【分配/暂存-检查任务表+任务检查项目表+ 检查内容表】", notes = "参数：任务编号，任务名称，检查项目 ，检查内容 ， 检查单位 ， 检查方式 ")
	@PostMapping(value = "/inspectionTaskDistribution")
	public ResponseWrapper inspectionTaskDistribution(@RequestBody TaskVO taskVO) {
		try {
			taskService.inspectionTaskDistribution(taskVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "已暂存", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "暂存失败", null);
		}
	}

	/**
	 * 制定任务检查数据新增对接
	 *
	 * @param taskTO
	 * @return
	 */
	@ApiOperation(value = "制定任务列表 【下发】", notes = "参数：任务编号，任务名称，计划编号，检查方式（0，远程。1、现场），检查组取得方式（0，指定。1、双随机。2、指定。），"
			+ "检查单位ID , 检查单位名称 , 下发人 , 下发人名称 , 下发时间 , 任务状态（0、待分配。1、待下发。2、已下发。3、已完成），"
			+ "任务类型，是否分配本级检查组值，被检单位选择方式（0,单一 1，组合），任务起日，任务止日，创建人，创建人编号，创建时间" + "刷新人" + "   sffp: 是否选择检查组")
	@PostMapping(value = "/inspectionTaskInsert")
	public ResponseWrapper inspectionTaskInsert(@RequestBody TaskVO taskVO) {
		try {
			int state = taskService.inspectionTaskInsert(taskVO);
			if (state == -1) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "下发计划ID和检查单位为空，下发异常", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "添加成功", state);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "添加失败", null);
		}
	}

	/**
	 * 制定任务下发/暂存 - 检查组+数据新增对接
	 *
	 * @param taskTO
	 * @return
	 */
    @ApiOperation(value = "制定任务新增页面【暂存/下发/下一步】 ", notes = "参数：是否分配本级检查组")
    @PostMapping(value = "/inspectionTaskInsertTeam")
    public ResponseWrapper inspectionTaskInsertTeam(@RequestBody TaskTeamVO taskTeamVO) {
        try {
            String rwId = taskService.inspectionTaskInsertTeam(taskTeamVO);
            if (StringUtils.isEmpty(rwId)) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), "成功", rwId);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
        }
    }

	/**
	 * 制定任务操作 回撤接口对接
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "制定任务列表【回撤】", notes = "参数：计划ID")
	@PostMapping(value = "/inspectionTaskGetDate/{jhId}")
	public ResponseWrapper inspectionTaskGetDate(@PathVariable("jhId") String jhId) {
		try {
			List<TaskVO> taskVo = taskService.inspectionTaskGetDate(jhId);
			if (taskVo.size() != 0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "撤销失败，子任务已下发", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "撤销成功", taskVo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 任务返回结果下发-新增
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务返回结果 【下发】")
	@PostMapping(value = "/inspectionTaskResultInsert")
	public ResponseWrapper updateInspectionTask(@RequestBody TaskVO taskVO) {
		try {
			taskService.updateInspectionTask(taskVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "下发成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "下发失败", null);
		}
	}

	/**
	 * 修改任务状态
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查【状态更新】", notes = "参数：rwId-任务编号 rwZt-任务状态 （0、待分配。1、待下发。2、已下发。3、已完成）")
	@PutMapping(value = "/inspectionTaskUpdateByEntity/{rwId}/{rwZt}")
	public ResponseWrapper inspectionTaskUpdateByEntity(@PathVariable("rwId") String rwId,
			@PathVariable("rwZt") Integer rwZt) {
		try {

			TaskVO taskVO = new TaskVO();

			taskVO.setRwId(rwId);
			taskVO.setRwZt(rwZt);

			TaskVO taskvo = taskService.inspectionTaskUpdate(taskVO);
			if (taskvo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}

			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", taskvo);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "更新失败", null);
		}
	}

	/**
	 * 获取任务ID主键策略方法 计划编号+001 格式
	 *
	 * @param jhId
	 * @return
	 */
	@ApiOperation(value = "获取任务ID主键策略方法  【计划编号+001 格式】", notes = "参数：jhId-计划编号")
	@GetMapping(value = "/inspectionTaskMaxCodeById/{jhId}")
	public ResponseWrapper inspectionTaskMaxCodeById(@PathVariable("jhId") String jhId) {
		try {
			String rwIdString = taskService.getTaskRwId(jhId);
			if (!StringUtils.isNotBlank(rwIdString)) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "生成主键策略失败", rwIdString);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rwIdString);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 根据条件导出日常检查管理信息
	 *
	 * @param taskQueryVO
	 * @param task
	 * @param request
	 * @param response
	 * @return
	 */
	@ApiOperation(value = "根据条件 【导出】", notes = "参数：查询条件")
	@PostMapping(value = "/inspectionTaskExport")
	public ResponseWrapper inspectionTaskExport(@RequestBody TaskQueryVO taskQueryVO) {
		try {
			List<TaskVO> taskVo = taskService.exportTask(taskQueryVO);
			if (taskVo.size() == 0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，任务不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), taskVo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 检查任务内容数据 修改
	 *
	 * @param taskVO
	 */
	@ApiOperation(value = "检查任务内容数据 【更新】")
	@PutMapping(value = "/inspectionTaskUpdate")
	public ResponseWrapper inspectionTaskUpdate(@RequestBody TaskVO taskVO) {
		try {
			taskVO = taskService.inspectionTaskUpdate(taskVO);
			if (taskVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "更新失败", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", taskVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 检查任务-归档管理
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "检查任务-【归档管理】")
	@PutMapping(value = "/inspectionTaskGuiDang")
	public ResponseWrapper inspectionTaskGuiDang(@RequestBody TaskVO taskVO) {
		try {
			taskVO = taskService.inspectionTaskGdGl(taskVO);
			if (taskVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "归档未完成", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "归档成功", taskVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 检查任务数据 更新
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查 【更新】")
	@PutMapping(value = "/inspectionTaskEdit")
	public ResponseWrapper inspectionTaskEdit(@RequestBody TaskVO taskVO) {
		try {
			TaskVO vo = taskService.inspectionEditJcDate(taskVO);
			if (vo == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "保存失败", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", vo);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 * 检查任务数据 查询
	 *
	 * @param taskVO
	 * @return
	 */
	@ApiOperation(value = "任务检查 【数据】")
	@PostMapping(value = "/inspectionTaskMain")
	public ResponseWrapper inspectionTaskMain(@RequestBody TaskQueryVO taskQueryVO) {
		try {
			List<TaskVO> taskVOs = taskService.inspectionTaskMain(taskQueryVO);
			if (taskVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "查询数据为空", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", taskVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 *
	 * @Title: inspectionJhTaskCq @Description:方法描述:(任务派发计划定时任务检查是否超期
	 * 【数据】) @param @param taskQueryVO @param @return 设定文件 @return ResponseWrapper
	 * 返回类型 @throws
	 */
	@ApiOperation(value = "任务派发计划定时任务检查是否超期 【数据】")
	@PostMapping(value = "/inspectionJhTaskCq")
	public ResponseWrapper inspectionJhTaskCq(@RequestBody TaskQueryVO taskQueryVO) {
		try {
			List<TaskVO> taskVOs = taskService.inspectionJhTaskCq(taskQueryVO);
			if (taskVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "查询数据为空", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", taskVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
	}

	/**
	 *
	 * @Description: 通过任务下发人查询任务Id列表
	 * @author: 王帅
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过任务下发人查询任务Id列表", notes = "通过任务下发人查询任务Id列表")
	@PostMapping("/makers/taskIds")
	public ResponseWrapper getTaskIdsByMakers(@RequestParam List<String> makersId) {
		return ResponseWrapper.success(taskService.getTaskIdsByMakers(makersId));
	}

	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过组织机构Id或是创建人集合查询检查计划主键集合", notes = "通过组织机构Id或是创建人集合查询检查计划主键集合")
	@ApiImplicitParams({ @ApiImplicitParam(name = "orgCode", value = "组织机构编码", required = false, paramType = "query"),
			@ApiImplicitParam(name = "makersId", value = "创建人集合", dataType = "list", required = false, paramType = "query"),
			@ApiImplicitParam(name = "taskStatus", value = "任务状态", required = false, paramType = "query")})
	@GetMapping("/orgCodeOrMakers/planIds")
	public ResponseWrapper getPlanIdsByOrgCodeOrMakers(@RequestParam(name = "orgCode", required = false) String orgCode,
			@RequestParam(name = "makersId", required = false) List<String> makersId, @RequestParam(name = "taskStatus", required = false)String taskStatus) {
		return ResponseWrapper.success(taskService.getPlanIdsByOrgCodeOrMakers(orgCode, makersId, taskStatus));
	}


	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更申请", notes = "变更申请")
	@PostMapping("/task/apply")
	public ResponseWrapper taskChange(@RequestBody TaskChangeVO taskChangeVO) {
		return ResponseWrapper.success(taskService.taskChange(taskChangeVO));
	}


	/**
	 *
	 * @Description: 通过组织机构Id或是创建人集合查询检查计划主键集合
	 * @author: 王帅
	 * @param: @param  orgCode
	 * @param: @param  makersId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "变更审核", notes = "变更审核")
	@PostMapping("/task/examine")
	public ResponseWrapper taskExamine(@RequestBody TaskChangeVO taskChangeVO) {
		return ResponseWrapper.success(taskService.taskExamine(taskChangeVO));
	}



	@ApiOperation(value = "查询区级任务列表", notes = "变更审核")
	@PostMapping("/task/list")
	public ResponseWrapper taskList(@RequestBody ResultApplyQuery taskChangeVO) {
		return ResponseWrapper.success(taskService.taskList(taskChangeVO));
	}

	@ApiOperation(value = "更新检查人信息", notes = "更新检查人信息")
	@PostMapping("/task/updateTJczzy")
	public ResponseWrapper updateTJczzy(@RequestBody TaskVO taskVO) {
		try {
			taskService.updateTJczzy(taskVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), "更新成功", null);
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "更新失败", null);
		}
	}

}
