package com.unis.inspectiontask.server.controller;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.unis.common.utils.ResponseWrapper;
import com.unis.inspectiontask.common.vo.MemberVO;
import com.unis.inspectiontask.common.vo.OrganizeVO;
import com.unis.inspectiontask.common.vo.TaskVO;
import com.unis.inspectiontask.common.vo.TeamVO;
import com.unis.inspectiontask.server.service.TaskService;
import com.unis.inspectiontask.server.service.TeamService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;

/**
 * 
 * @ClassName: EvasionController
 * @Description: 人员、被检单位规避controller
 * @author LiuFeng
 * @date 2019年8月24日 下午2:05:09
 *
 */
@RestController
@Slf4j
@Api(value = "检查组管理", tags = "检查组信息维护")
public class TeamController {

	@Autowired
	private TeamService teamService;
	
	@Autowired
	private TaskService taskService;
	
	/**
	 * 
	 * @Title: saveInspectionTeams 
	 * @Description: 检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "检查组信息保存", notes = "参数：")
    @PostMapping(value = "/inspectionTeams")
    public ResponseWrapper saveInspectionTeams(@RequestBody List<TeamVO> teamVOs){
        try {
        	boolean boo = true;
        	
    		for(TeamVO teamVO:teamVOs) {
    			List<MemberVO> mlist = teamVO.getMembers();
            	List<OrganizeVO> oList = teamVO.getOrganizes();
            	
    			if(StringUtils.isBlank(teamVO.getRwId()) || mlist == null || oList == null
    					|| (mlist != null && mlist.size() == 0) || (oList != null && oList.size() == 0)) {
    				boo = false;
    				break;
    			}
    		}
    		
    		if(boo) {
    			teamService.saveInspectionTeams(teamVOs);
    			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", null);
    		}else {
    			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"保存失败，请检查检查组参数");
    		}
        	
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "保存失败", null);
        }
    }
	
	/**
	 * 
	 * @Title: saveInspectionTeams 
	 * @Description: 制定任务检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "制定任务检查组信息暂存/下发", notes = "参数：")
    @PostMapping(value = "/saveInspectionPlanTeams")
    public ResponseWrapper saveInspectionPlanTeams(@RequestBody List<TeamVO> teamVOs){
        try {
        	boolean boo = true;
    		for(TeamVO teamVO:teamVOs) {
    			List<MemberVO> mlist = teamVO.getMembers();
            	List<OrganizeVO> oList = teamVO.getOrganizes();
    			if(StringUtils.isBlank(teamVO.getRwId()) || mlist == null || oList == null
    					|| (mlist != null && mlist.size() == 0) || (oList != null && oList.size() == 0)) {
    				boo = false;
    				break;
    			}
    		}
    		if(boo) {
    			teamService.saveInspectionPlanTeams(teamVOs);
    			return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", null);
    		}else {
    			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"保存失败，请检查检查组参数");
    		}
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "保存失败", null);
        }
    }
	
	
	/**
	 * 
	 * @Title: saveInspectionTeams 
	 * @Description: 检查组信息保存
	 * @param teamVO
	 * @param rwId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "检查组信息修改", notes = "参数：检查组VO")
    @PutMapping(value = "/inspectionTeams")
    public ResponseWrapper updateInspectionTeams(@RequestBody List<TeamVO> teamVOs){
        try {
        	boolean boo = true;
    		for(TeamVO teamVO:teamVOs) {
    			List<MemberVO> mlist = teamVO.getMembers();
            	List<OrganizeVO> oList = teamVO.getOrganizes();
            	
    			if(StringUtils.isBlank(teamVO.getRwId()) || mlist == null || oList == null
    					|| (mlist != null && mlist.size() == 0) || (oList != null && oList.size() == 0)) {
    				boo = false;
    				break;
    			}
    		}
    		
    		if(boo) {
    			teamService.updateInspectionTeams(teamVOs);
            	return ResponseWrapper.success(HttpStatus.OK.value(), "修改成功", null);
    		}else {
    			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"保存失败，请检查检查组参数");
    		}
        	
        	
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "修改失败", null);
        }
    }
	
	/**
	 * 
	 * @Title: saveInspectionTeams 
	 * @Description: 根据当前用户查询被检单位
	 * @param userId
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据用户ID查询被检单位", notes = "参数：用户id")
    @GetMapping(value = "/inspectionUnit/{userId}")
    public ResponseWrapper getInspectionUnit(@PathVariable(value="userId")String userId){
        try {

        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", teamService.getInspectionUnit(userId));
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	/**
	 * 
	 * @Title: getIinspectionTeamList 
	 * @Description: 根据用户id获取检查组列表
	 * @param taskId 任务编号
	 * @return ResponseWrapper
	 * @throws
	 */
	@ApiOperation(value = "根据任务编号查询被检单位", notes = "参数：任务编号")
    @GetMapping(value = "/inspectionTeamList/{taskId}")
    public ResponseWrapper getIinspectionTeamList(@PathVariable(value="taskId")String taskId){
        try {

        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", teamService.getIinspectionTeamList(taskId));
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	/**
	 * 
	 * @Title: getIinspectionTeam
	 * @Description: 根据组织编号判断是否在检查组
	 * @param jczId 检查组id
	 * @param orgId 组织id
	 * @return ResponseWrapper  data: 0 :不再检查组   1:在检查组 
	 * @throws
	 */
	@ApiOperation(value = "根据组织编号判断是否在检查组", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/isInspectionTeam")
    public ResponseWrapper isIinspectionTeam(
    		@ApiParam(value="检查组id",name="jczId",required=true)
    		@RequestParam(value="jczId")Long jczId,
    		@ApiParam(value="组织编号",name="orgId",required=true)
    		@RequestParam(value="orgId")String orgId){
        try {
        	Integer result = teamService.isIinspectionTeam(jczId,orgId);
        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功",result);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	/**
	 * 
	 * @Title: taskList
	 * @Description: 根据检查组人员编号判断查询任务列表
	 * @param rybh 人员编号
	 * @return 
	 * @throws
	 */
	@ApiOperation(value = "根据检查组人员编号判断查询任务列表", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/taskList/{rybh}")
    public ResponseWrapper getTaskList(@PathVariable(value="rybh")String rybh){
        try {
        	List<TaskVO> list = taskService.getTaskListByRybh(rybh, "");
        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功",list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	
	/**
	 * 
	 * @Title: taskList
	 * @Description: 根据检查组人员编号 任务类型   判断查询任务列表
	 * @param rybh 人员编号 rwlx任务类型
	 * @return 
	 * @throws
	 */
	@ApiOperation(value = "根据检查组人员编号/任务类型判断查询任务列表", notes = "参数：组织编号,检查组id")
    @GetMapping(value = "/taskListMore/{rybh}/{rwlx}")
    public ResponseWrapper getTaskListMore(@PathVariable(value="rybh")String rybh,@PathVariable(value="rwlx")String rwlx){
        try {
        	List<TaskVO> list = taskService.getTaskSimpleListByRybh(rybh,rwlx);
        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功",list);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	
	/**
	 * 
	 * @Title: getInspectionTeam
	 * @Description: 根据任务编号和被检单位id查询检查组信息
	 * @param rwId 任务编号
	 * @param bjdwId 被检企业id
	 * @return 
	 * @throws
	 */
	@ApiOperation(value = "根据任务编号和被检单位id查询检查组信息", notes = "参数：任务编号,被检企业id")
    @GetMapping(value = "/inspectionTeam/{rwId}/{bjdwId}")
    public ResponseWrapper getInspectionTeam(
    		@PathVariable(value="rwId")String rwId,
    		@PathVariable(value="bjdwId")String bjdwId){
		
        try {
        	TeamVO result = teamService.getInspectionTeam(rwId,bjdwId);
        	return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功",result);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
	
	/**
	 * 根据任务编号删除检查组所有信息
	 * @param teamVO
	 */
	@ApiOperation(value = "根据任务编号删除检查组所有信息", notes = "参数：任务编号")
    @DeleteMapping(value = "/deleteInspectionTeams/{rwId}")
	public ResponseWrapper deleteInspectionTeams(@PathVariable(value="rwId")String rwId) {
		 try {
			 	teamService.deleteInspectionTeams(rwId);
				return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
			} catch (Exception e) {
				log.error(e.getMessage());
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),"删除失败",null);
		  }
	}
	
	/**
	 * 
	 * @Description: 通过组员Id获取任务Id集合
	 * @author: 王帅
	 * @param: @param  memberId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	@ApiOperation(value = "通过组员Id获取任务Id集合", notes = "通过组员Id获取任务Id集合")
	@GetMapping(value = "/taskIds/{memberId}")
	public ResponseWrapper getTaskIdsListByMemberId(@PathVariable(value = "memberId")String memberId) {
		return ResponseWrapper.success(teamService.getTaskIdsListByMemberId(memberId));
	}
}
