package com.unis.inspectiontask.server.domain;
import java.util.*;
import java.util.stream.Collectors;

import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.druid.util.StringUtils;
import com.google.common.collect.Lists;
import com.unis.common.utils.LsBeanUtils;
import com.unis.inspectiontask.common.constant.TaskStatusConstant;
import com.unis.inspectiontask.common.vo.MemberVO;
import com.unis.inspectiontask.common.vo.OrganizeVO;
import com.unis.inspectiontask.common.vo.TeamVO;
import com.unis.inspectiontask.server.dao.TBjdwDao;
import com.unis.inspectiontask.server.dao.TJcrwDao;
import com.unis.inspectiontask.server.dao.TJczBjdwDao;
import com.unis.inspectiontask.server.dao.TJczDao;
import com.unis.inspectiontask.server.dao.TJczzyDao;
import com.unis.inspectiontask.server.entity.TBjdwDO;
import com.unis.inspectiontask.server.entity.TJczBjdwDO;
import com.unis.inspectiontask.server.entity.TJczDO;
import com.unis.inspectiontask.server.entity.TJczzyDO;
import lombok.Data;
import tk.mybatis.mapper.entity.Example;
import tk.mybatis.mapper.entity.Example.Criteria;

/** 
 * @ClassName: TeamDomain 
 * @Description: 检查组管理 Domain
 * @author LiuFeng 
 * @date 2019年8月24日 下午2:47:56 
 */
@Data
@Component
public class TeamDomain {

	@Autowired
	private TJczDao jczDao;
	
	@Autowired
	private TJczzyDao jczzyDao;
	
	@Autowired
	private TJczBjdwDao jczBjdwDao;
	
	@Autowired
	private TBjdwDao bjdwDao;
	
	@Autowired
	private TJcrwDao jcrwDao;

	/** 
	 * @Title: saveInspectionTeams 
	 * @Description: 添加检查组
	 * @param teamVOs
	 * @return void
	 * @throws 
	 */
	@Transactional
	public void saveInspectionTeams(List<TeamVO> teamVOs,String state) {
       //根除
		if ( !TaskStatusConstant.XF.getValue().equals(state)) {
			deleteTeam(state);
		}
       //在新增检查组
		for(TeamVO teamVO : teamVOs) {
			TJczDO jczDO = new TJczDO();
			jczDO.setJczName(teamVO.getJczName());
			jczDO.setRwId(teamVO.getRwId());
			jczDO.setCreateDate(teamVO.getCreateDate());
			jczDO.setCreator(teamVO.getCreator());
			jczDO.setCreatorCode(teamVO.getCreatorCode());
			jczDao.insertSelective(jczDO);
			List<MemberVO> memberVOs = teamVO.getMembers();
			for(MemberVO memberVO :memberVOs) {
				memberVO.setJczId(jczDO.getId());
				memberVO.setCreateDate(teamVO.getCreateDate());
				memberVO.setCreator(teamVO.getCreator());
				memberVO.setCreatorCode(teamVO.getCreatorCode());
			}
			jczzyDao.insertList(memberVOs);
			
			List<TBjdwDO> tBjdwDOs = new ArrayList<>();
			List<OrganizeVO> organizeVOs = teamVO.getOrganizes();
			for(OrganizeVO organizeVO:organizeVOs) {
				organizeVO.setJczId(jczDO.getId());
				organizeVO.setCreateDate(teamVO.getCreateDate());
				organizeVO.setCreator(teamVO.getCreator());
				organizeVO.setCreatorCode(teamVO.getCreatorCode());
				
				TBjdwDO tBjdwDO = new TBjdwDO();
				tBjdwDO.setBjdwId(organizeVO.getBjdwId());
				tBjdwDO.setQybm(organizeVO.getQybm());
				tBjdwDO.setBjdwName(organizeVO.getBjdwName());
				tBjdwDO.setBjdwAddress(organizeVO.getBjdwAddress());
				tBjdwDO.setBjdwFzr(organizeVO.getBjdwFzr());
				tBjdwDO.setBjdwFzrPhone(organizeVO.getBjdwFzrPhone());
				tBjdwDO.setRwId(teamVO.getRwId());
				tBjdwDO.setCreateDate(teamVO.getCreateDate());
				tBjdwDO.setCreator(teamVO.getCreator());
				tBjdwDO.setCreatorCode(teamVO.getCreatorCode());
				tBjdwDOs.add(tBjdwDO);
			}
			bjdwDao.insertList(tBjdwDOs);
			jczBjdwDao.insertList(organizeVOs);
			//检查组分配成功，更新任务状态（0、待分配。1、待下发。2、已下发。3、已完成）
			if (teamVO.getRwZt() != null && teamVO.getRwZt() != 2) {
				jcrwDao.updateTaskStatus(teamVO.getRwId(), 1);
			}
		}

	}

	/** 
	 * @Title: getInspectionUnit 
	 * @Description: 根据userId查询被检单位列表
	 * @param userId
	 * @return List<OrganizeVO>
	 * @throws 
	 */
	public List<OrganizeVO> getInspectionUnit(String userId) {
		List<OrganizeVO> organizeVOs = new ArrayList<OrganizeVO>();
		List<TBjdwDO> bjdwDOs = bjdwDao.selectByUserId(userId);
		for(TBjdwDO dwDo : bjdwDOs) {
			OrganizeVO organizeVO = new OrganizeVO();
			LsBeanUtils.copyAllProperties(dwDo, organizeVO);
			organizeVOs.add(organizeVO);
		}
		return organizeVOs;
	}

	/** 
	 * @Title: getIinspectionTeamList 
	 * @Description: 根据任务编号查询检查组列表
	 * @param taskId
	 * @return List<TeamVO>
	 * @throws 
	 */
	public List<TeamVO> getIinspectionTeamList(String taskId) {
		List<TeamVO> teamVOs = new ArrayList<>();
		List<TJczDO> tJczDOs = jczDao.selectByTaskId(taskId);
		for(TJczDO tJczDO:tJczDOs) {
			TeamVO teamVO = new TeamVO();
			teamVO.setId(tJczDO.getId());
			teamVO.setJczName(tJczDO.getJczName());
			teamVO.setRwId(tJczDO.getRwId());
			List<TJczzyDO> tJczzyDOs = jczzyDao.selectByJczId(tJczDO.getId());
			List<MemberVO> memberVOs = new ArrayList<MemberVO>();
			LsBeanUtils.copyCollection(tJczzyDOs, memberVOs, MemberVO.class);
			teamVO.setMembers(memberVOs);
			TBjdwDO tBjdwDO=new TBjdwDO();
			tBjdwDO.setRwId(tJczDO.getRwId());
			tBjdwDO.setId(tJczDO.getId());
			List<TBjdwDO> tBjdwDOs = bjdwDao.selectByJczId(tBjdwDO);
			List<OrganizeVO> organizeVOs = new ArrayList<>();
			LsBeanUtils.copyCollection(tBjdwDOs, organizeVOs, OrganizeVO.class);
			teamVO.setOrganizes(organizeVOs);
			teamVOs.add(teamVO);
		}
		return teamVOs;
	}

	/** 
	 * @Title: updateInspectionTeams 
	 * @Description: 批量更新检查组信息
	 * @param teamVOs
	 * @return void
	 * @throws 
	 */
	public void updateInspectionTeams(List<TeamVO> teamVOs) {
		List<MemberVO> memberVOs = new ArrayList<>();
		for(TeamVO teamVO:teamVOs) {
			if(teamVO.getMembers() != null) {
				memberVOs.addAll(teamVO.getMembers());
				for(MemberVO memberVO :memberVOs) {
					memberVO.setRefresher(teamVO.getRefresher());
					memberVO.setRefresherCode(teamVO.getRefresherCode());
					memberVO.setRefreshTime(teamVO.getRefreshTime());
				}
			}
		}
		
		if(memberVOs.size() > 0) {
			jczzyDao.batchUpdateOrSave(memberVOs);
		}
	}

	/** 
	 * @Title: isIinspectionTeam 
	 * @Description: 根据组织编号判断是否在检查组
	 * @param jczId
	 * @param orgId
	 * @return Integer
	 * @throws 
	 */
	public Integer isIinspectionTeam(Long jczId, String orgId) {
		TJczBjdwDO jczBjdwDO =  jczBjdwDao.selectByJczIdAndOrgId(jczId,orgId);
		if(jczBjdwDO != null)
			return 1;
		return 0;
	}

	/** 
	 * @Title: getInspectionTeam 
	 * @Description: 根据任务编号和被检单位id查询检查组信息
	 * @param rwId 任务编号
	 * @param bjdwId 被检企业id
	 * @return TeamVO
	 * @throws 
	 */
	public TeamVO getInspectionTeam(String rwId, String bjdwId) {
		TJczDO tJczDO = jczDao.selectInspectionTeam(rwId,bjdwId);
		if(tJczDO != null) {
			TeamVO teamVO = new TeamVO();
			teamVO.setId(tJczDO.getId());
			teamVO.setJczName(tJczDO.getJczName());
			teamVO.setRwId(tJczDO.getRwId());
			List<TJczzyDO> tJczzyDOs = jczzyDao.selectByJczId(tJczDO.getId());
			List<MemberVO> memberVOs = new ArrayList<MemberVO>();
			LsBeanUtils.copyCollection(tJczzyDOs, memberVOs, MemberVO.class);
			teamVO.setMembers(memberVOs);

			TBjdwDO tBjdwDO=new TBjdwDO();
			tBjdwDO.setRwId(tJczDO.getRwId());
			tBjdwDO.setId(tJczDO.getId());
			List<TBjdwDO> tBjdwDOs = bjdwDao.selectByJczId(tBjdwDO);
			List<OrganizeVO> organizeVOs = new ArrayList<>();
			LsBeanUtils.copyCollection(tBjdwDOs, organizeVOs, OrganizeVO.class);
			teamVO.setOrganizes(organizeVOs);

			return teamVO;
		}
		return null;
	}

	/**
	 * 根据任务编号删除检查组所有信息zq
	 * @param rwId
	 */
	public void deleteTeam(String rwId) {
		//根据任务ID 查询 
		List<TJczDO> jczsList = jczDao.selectByTaskId(rwId);
		for (TJczDO tJczDO : jczsList) {
			TJczBjdwDO tJczBjdwDO=new TJczBjdwDO();
			tJczBjdwDO.setJczId(tJczDO.getId());
			List<TJczBjdwDO> jczBjdwList= jczBjdwDao.selectByPrimaryJczKey(tJczBjdwDO);
			for (TJczBjdwDO tJczBjdws : jczBjdwList) {
				tJczBjdwDO.setId(tJczBjdws.getId());
				jczBjdwDao.deleteByPrimaryJcKey(tJczBjdwDO);
			}
			//删除检查组组员
			TJczzyDO jczzyDo=new TJczzyDO();
			jczzyDo.setJczId(tJczDO.getId());
			jczzyDao.deleteByPrimaryJCKey(jczzyDo);
		}
		jczDao.deleteTeam(rwId);
		bjdwDao.delete(rwId);
		
	}
	
	/**
	 * 
	 * @Description: 通过组员Id获取任务Id集合
	 * @author: 王帅
	 * @param: @param  memberId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	public List<String> getTaskIdsListByMemberId(String memberId) {
		// 组员Id为空则返回null
		if (StringUtils.isEmpty(memberId)) {
			return null;
		}
		// 根据组员id查询组Id集合
		Example example = new Example(TJczzyDO.class);
		Criteria criteria = example.createCriteria();
		criteria.andIn("zyId", Arrays.asList(memberId.split(",")));
		List<TJczzyDO> memberList = jczzyDao.selectByExample(example);
		if (CollectionUtils.isNotEmpty(memberList)) {
			// 检查组Id集合
			Set<Long> teamIdList = memberList.stream().map(TJczzyDO::getJczId)
					.collect(Collectors.toCollection(TreeSet::new));
			// 根据检查组查询所有任务Id
			Example exampleTeam = new Example(TJczDO.class);
			Criteria criteriaTeam = exampleTeam.createCriteria();
			criteriaTeam.andIn("id", teamIdList);
			criteriaTeam.andIsNotNull("rwId");
			List<TJczDO> teamList = jczDao.selectByExample(exampleTeam);
			if (CollectionUtils.isNotEmpty(teamList)) {
				Set<String> taskIds = teamList.stream().map(TJczDO::getRwId)
						.collect(Collectors.toCollection(TreeSet::new));
				return Lists.newArrayList(taskIds);
			}
		}

		return null;
	}
}
