package com.unis.inspectiontask.server.service;

import java.util.List;

import com.unis.inspectiontask.common.vo.OrganizeVO;
import com.unis.inspectiontask.common.vo.TeamVO;

/** 
 * @ClassName: TeamService 
 * @Description: 检查组信息service
 * @author LiuFeng 
 * @date 2019年8月24日 下午5:52:24  
 */
public interface TeamService {

	/** 
	 * @Title: saveInspectionTeams 
	 * @Description: 保存检查组信息
	 * @param teamVOs
	 * @return void
	 * @throws 
	 */
	void saveInspectionTeams(List<TeamVO> teamVOs);

	/** 
	 * @Title: getInspectionUnit 
	 * @Description: 根据当前登录用户id，获取被检单位列表
	 * @param userId
	 * @return List<OrganizeVO>
	 * @throws 
	 */
	List<OrganizeVO> getInspectionUnit(String userId);

	/** 
	 * @Title: getIinspectionTeamList 
	 * @Description: 根据任务编号获取检查组列表
	 * @param @param taskId
	 * @param @return
	 * @return Object
	 * @throws 
	 */
	List<TeamVO> getIinspectionTeamList(String taskId);

	/** 
	 * @Title: updateInspectionTeams 
	 * @Description: 检查组信息修改
	 * @param teamVOs
	 * @throws 
	 */
	void updateInspectionTeams(List<TeamVO> teamVOs);

	/** 
	 * @Title: isIinspectionTeam 
	 * @Description: 根据组织编号判断是否在检查组
	 * @param jczId
	 * @param orgId
	 * @return Integer
	 * @throws 
	 */
	Integer isIinspectionTeam(Long jczId, String orgId);

	/** 
	 * @Title: getInspectionTeam 
	 * @Description: 根据任务编号和被检单位id查询检查组信息
	 * @param rwId 任务编号
	 * @param bjdwId 被检企业id
	 * @return TeamVO
	 * @throws 
	 */
	TeamVO getInspectionTeam(String rwId, String bjdwId);

	/**
	 * 根据任务编号删除检查组所有信息
	 * @param rwId
	 */
	void deleteInspectionTeams(String rwId);

	/**
	 * 制定任务检查组信息暂存/下发
	 * @param teamVOs
	 */
	void saveInspectionPlanTeams(List<TeamVO> teamVOs);
	
	/**
	 * 
	 * @Description: 通过组员Id获取任务Id集合
	 * @author: 王帅
	 * @param: @param  memberId
	 * @param: @return 参数
	 * @return: List<String> 返回类型
	 */
	public List<String> getTaskIdsListByMemberId(String memberId);

}
