package com.unis.inspectiontask.server.service.impl.mq;

import java.util.List;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.inspectiontask.common.constant.BacklogConstant;
import com.unis.inspectiontask.common.vo.backlog.BacklogAddVO;
import com.unis.inspectiontask.common.vo.backlog.BacklogUpdateVO;
import com.unis.inspectiontask.common.vo.backlog.ReceiverCollectionVO;
import com.unis.inspectiontask.server.service.mq.BacklogMQService;

import lombok.extern.slf4j.Slf4j;

/**
 *
 * @Description：待办服务实现
 * @author：王帅
 * @date: 2020年2月27日
 */
@Service
@Slf4j
public class BacklogMQServiceImpl implements BacklogMQService {

	@Autowired
	private RabbitTemplate amqpTemplate;

	@Override
	public void sendMsg(Object obj, String type) {
		try {
			this.amqpTemplate.convertAndSend(BacklogConstant.BACKLOG_EXCHANGE, "backlog." + type, obj);
		} catch (Exception e) {
			log.error("{}待办消息发送异常,待办实体{}", type, obj, e);
		}
	}

	@Override
	public void addNeedToDeals(String id, String title, String status, String statusName, String itemUrl,
			String itemQuery, String itemHavQuery, String itemHavUrl, List<ReceiverCollectionVO> userList) {
		if(CollectionUtils.isEmpty(userList)) {
			System.out.println("****************待办用户集合为空*****************");
			return;
		}
		if(StringUtils.isEmpty(title)) {
			System.out.println("****************没有正确的title*****************");
			return;
		}
		System.out.println("*************进入创建待办************");
		BacklogAddVO record = new BacklogAddVO();
		record.buildAddVO(record);
		record.setItemId(id);
		record.setItemName(title);
		record.setCompanyName(CurrentUtil.getOrgName());
		record.setItemQueryHaveDone(itemHavQuery);
		record.setItemUrlHaveDone(itemHavUrl);
		if(!StringUtils.isEmpty(status)) {
			record.setItemStatus(Integer.valueOf(status));
		}
		record.setItemStatusName(statusName);
		record.setItemUrl(itemUrl);
		record.setItemQuery(itemQuery);
		// 另起线程执行待办
		new Thread(new Runnable() {
			@Override
			public void run() {
				for (ReceiverCollectionVO userVO : userList) {
					System.out.println("********************接收人*******************");
					System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
					System.out.println("********************************************");
					record.setReceiver(userVO.getUserName());
					record.setReceiverId(userVO.getUserId());
					// 需要将对象序列化成JSONObject
					if(id.contains("5000110-1")) {//日常检查
						if(userVO.getRylx()==1) {
							record.setItemName(title.replace("）待盖章", "）待整改"));
							sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
						} else if(userVO.getRylx()==0)  {
							record.setItemName(title.replace("）待整改","）待盖章"));
							sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
						} else {
							sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
						}
					} else {
						sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
					}
				}
			}
		}).start();
	}



	@Override
	public void addDeals(String itemId, String itemName, String status, String statusName) {
		try {

			System.out.println("*************进入创建已办************");
			BacklogUpdateVO updateVO = new BacklogUpdateVO();
			updateVO.buildUpdateVO(updateVO);
			updateVO.setItemId(itemId);
			updateVO.setItemName(itemName);
			updateVO.setItemStatus(Integer.valueOf(status));
			updateVO.setItemStatusName(statusName);
			sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");
		} catch (Exception e) {
			//: handle exception
		}
	}

}
